<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="327"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Comprar la versión Ultimate para financiar el desarrollo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="412"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>El archivo %1/%2, el tamaño: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="646"/>
        <source>Copy list</source>
        <translation>Lista de copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="648"/>
        <source>Move list</source>
        <translation>Lista de movimiento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1076"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1077"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1078"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1080"/>
        <source>File Name, 0KB</source>
        <translation>Nombre de archivo, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1274"/>
        <location filename="../../interface.cpp" line="1286"/>
        <location filename="../../interface.cpp" line="1298"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1373"/>
        <location filename="../../interface.cpp" line="1377"/>
        <location filename="../../interface.cpp" line="1379"/>
        <source>%1 %2% of %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="35"/>
        <source>From:</source>
        <translation>De:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="65"/>
        <source>To:</source>
        <translation>Para:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="226"/>
        <source>&amp;More</source>
        <translation>&amp;Más</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="246"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="260"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="271"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="118"/>
        <source>Close on transfer completion</source>
        <translation>Cerca de finalización de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="286"/>
        <source>Limit copy speed to:</source>
        <translation>Limitar la velocidad de copia en:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="329"/>
        <source>Transfer list</source>
        <translation>Lista de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="352"/>
        <source>Move the selected items to the top</source>
        <translation>Mueve los elementos seleccionados a la parte superior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="378"/>
        <source>Move up the selected items</source>
        <translation>Mueva los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="404"/>
        <source>Move down the selected items</source>
        <translation>Bajar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="430"/>
        <source>Move the selected items to the bottom</source>
        <translation>Mueve los elementos seleccionados a la parte inferior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="456"/>
        <source>Add file/folder</source>
        <translation>Agregar archivo/carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="485"/>
        <source>Delete the selected items</source>
        <translation>Eliminar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="511"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="540"/>
        <source>Export the transfer list</source>
        <translation>Exportar la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="566"/>
        <source>Import the transfer list</source>
        <translation>Importe la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="621"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="628"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="663"/>
        <location filename="../../interface.ui" line="732"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="683"/>
        <source>Export the errors into transfer list</source>
        <translation>Exportar los errores en la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="722"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="727"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="741"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="778"/>
        <source>Add file</source>
        <translation>Añadir archivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="787"/>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Move file(s)</source>
        <translation>Mover archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Move folder</source>
        <translation>Mueva la carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Copy file(s)</source>
        <translation>Copia el archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Copy folder</source>
        <translation>Copia la carpeta</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation>Mostrar progresión dual</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Mostrar la velocidad como principales informaciones</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Uso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Comience con el &quot;botón más&quot; empujada</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Minimizar en cerca de la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Al final de la copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitar la velocidad de copia de</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>Haga clic para editar el color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>Informations</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Visualización</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>Velocidad con barra de progreso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>Progresión de color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>Mostrar progresión en el título</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Siempre visible</translation>
    </message>
</context>
</TS>
